@@ -1,4 +1,6 @@
-" Basic interface for a cost function "
+"""
+Basic interface for a cost function
+"""
 from abc import ABCMeta, abstractmethod
 
 from monty.json import MSONable
@@ -7,8 +9,12 @@ from rxn_network.core.reaction import Reaction
 
 
 class CostFunction(MSONable, metaclass=ABCMeta):
-    "Base definition for a cost function"
+    """
+    Base definition for a cost function
+    """
 
     @abstractmethod
     def evaluate(self, rxn: Reaction) -> float:
-        "Evaluates the total cost function on a reaction"
+        """
+        Evaluates the total cost function on a reaction
+        """
